PCB Environment: UserSettings Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions | Data Fields
UserSettings Class Reference

## Public Member Functions
void | AddPath (const std::string_view &s)
void | sleepForActionDelay (uint times=1) const
std::string | str () const

## Static Public Member Functions
static const UserSettings & | get ()
static void | LoadFile (const std::string &path)
static void | LoadJSON (const std::string &json)
static UserSettings & | edit ()

## Data Fields
uint32_t | MaxGridCells {1u << 26}
uint64_t | AgentTimeoutUSecs {0}
float | AStarViaCostFactor {1.0f}
struct { |
uint WindowSize [2] {1024, 768} |
float PointSize {1.0f} |
uint FPS {40} |
uint SidePaneWidth {256} |
uint LockSteppingGranularity {0} |
uint ActionDelayUSecs {0} |
bool EnableRendering {true} |
bool VSync {true} |
bool GridLinesVisible {false} |
bool GridPointsVisible {false} |
bool FootprintsVisible {false} |
bool RatsNestVisible {false} |
bool TriangulationVisible {false} |
bool RoutePreview {true} |
} | UI
struct { |
float PerVia {0.0f} |
float PerDisconnect {-5.0f} |
float AnyDisconnect {0.0f} |
} | Reward
struct { |
std::string GLSL |
std::string JSON |
std::string QTUI |
} | Paths

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UserSettings.hpp